@@ -789,4 +789,35 @@ public class LiferayWSUserManager implements UserManager{
 
 	}
 
+	@Override
+	public List<GCubeUser> listUsers(int start, int end) throws UserManagementSystemException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	@Override
+	public int getUsersCount() throws UserManagementSystemException {
+		// TODO Auto-generated method stub
+		return 0;
+	}
+
+	@Override
+	public List<GCubeUser> searchUsersByGroup(String keywords, long groupId) throws GroupRetrievalFault {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	@Override
+	public List<GCubeUser> listUsersByGroup(long groupId, int start, int end)
+			throws UserManagementSystemException, GroupRetrievalFault, UserRetrievalFault {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	@Override
+	public int getGroupUsersCount(long groupId) throws GroupRetrievalFault {
+		// TODO Auto-generated method stub
+		return 0;
+	}
+
 }
